( cd sbin ; rm -rf swapoff )
( cd sbin ; ln -sf swapon swapoff )
( cd bin ; rm -rf mount )
( cd bin ; ln -sf ../sbin/mount mount )
( cd bin ; rm -rf umount )
( cd bin ; ln -sf ../sbin/umount umount )
( cd usr/sbin ; rm -rf ramsize )
( cd usr/sbin ; ln -sf rdev ramsize )
( cd usr/sbin ; rm -rf vidmode )
( cd usr/sbin ; ln -sf rdev vidmode )
( cd usr/sbin ; rm -rf rootflags )
( cd usr/sbin ; ln -sf rdev rootflags )
( cd usr/bin ; rm -rf linux32 )
( cd usr/bin ; ln -sf setarch linux32 )
( cd usr/bin ; rm -rf linux64 )
( cd usr/bin ; ln -sf setarch linux64 )
( cd usr/bin ; rm -rf i386 )
( cd usr/bin ; ln -sf setarch i386 )
( cd lib ; rm -rf libuuid.so.1 )
( cd lib ; ln -sf libuuid.so.1.3.0 libuuid.so.1 )
( cd lib ; rm -rf libblkid.so.1 )
( cd lib ; ln -sf libblkid.so.1.1.0 libblkid.so.1 )
( cd usr/lib ; rm -rf libuuid.so )
( cd usr/lib ; ln -sf ../../lib/libuuid.so.1.3.0 libuuid.so )
( cd usr/lib ; rm -rf libblkid.so )
( cd usr/lib ; ln -sf ../../lib/libblkid.so.1.1.0 libblkid.so )
